==> mongodb-src-r3.0.14.tar.gz: mongodb-src-r3.0.14/src/mongo/db/fts/tokenizer.h <==
// tokenizer.h

/**
*    Copyright (C) 2012 10gen Inc.
*
*    This program is free software: you can redistribute it and/or  modify
*    it under the terms of the GNU Affero General Public License, version 3,
*    as published by the Free Software Foundation.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU Affero General Public License for more details.
*
*    You should have received a copy of the GNU Affero General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*    As a special exception, the copyright holders give permission to link the
*    code of portions of this program with the OpenSSL library under certain
*    conditions as described in each individual source file and distribute
*    linked combinations including the program with the OpenSSL library. You
*    must comply with the GNU Affero General Public License in all respects for
*    all of the code used other than as permitted herein. If you modify file(s)
*    with this exception, you may extend this exception to your version of the
*    file(s), but you are not obligated to do so. If you do not wish to do so,
*    delete this exception statement from your version. If you delete this
*    exception statement from all source files in the program, then also delete
*    it in the license file.
*/


#pragma once

#include <string>

#include "mongo/base/string_data.h"
#include "mongo/db/fts/fts_language.h"
#include "mongo/platform/unordered_map.h"
#include "mongo/platform/unordered_set.h"

namespace mongo {

namespace fts {

struct Token {
    enum Type { WHITESPACE, DELIMITER, TEXT, INVALID };
    Token(Type type, const StringData& data, unsigned offset, bool previousWhiteSpace)
        : type(type), data(data), offset(offset), previousWhiteSpace(previousWhiteSpace) {}

    bool ok() const {
        return type != INVALID;
    }

    Type type;
    StringData data;
    unsigned offset;
    bool previousWhiteSpace;
};

class Tokenizer {
public:
    Tokenizer(const FTSLanguage& language, const StringData& str);

    bool more() const;
    Token next();

private:
    Token::Type _type(char c) const;
    bool _skipWhitespace();

    unsigned _pos;
    bool _previousWhiteSpace;
    const StringData _raw;
    bool _english;
};
}
}

==> mongodb-src-r3.2.17.tar.gz: mongodb-src-r3.2.17/src/mongo/db/fts/tokenizer.h <==
// tokenizer.h

/**
*    Copyright (C) 2012 10gen Inc.
*
*    This program is free software: you can redistribute it and/or  modify
*    it under the terms of the GNU Affero General Public License, version 3,
*    as published by the Free Software Foundation.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU Affero General Public License for more details.
*
*    You should have received a copy of the GNU Affero General Public License
*    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*    As a special exception, the copyright holders give permission to link the
*    code of portions of this program with the OpenSSL library under certain
*    conditions as described in each individual source file and distribute
*    linked combinations including the program with the OpenSSL library. You
*    must comply with the GNU Affero General Public License in all respects for
*    all of the code used other than as permitted herein. If you modify file(s)
*    with this exception, you may extend this exception to your version of the
*    file(s), but you are not obligated to do so. If you do not wish to do so,
*    delete this exception statement from your version. If you delete this
*    exception statement from all source files in the program, then also delete
*    it in the license file.
*/


#pragma once

#include <string>

#include "mongo/base/string_data.h"
#include "mongo/db/fts/fts_language.h"

namespace mongo {

namespace fts {

struct Token {
    enum Type { WHITESPACE, DELIMITER, TEXT, INVALID };
    Token(Type type, StringData data, unsigned offset) : type(type), data(data), offset(offset) {}

    bool ok() const {
        return type != INVALID;
    }

    Type type;
    StringData data;
    unsigned offset;
};

class Tokenizer {
    MONGO_DISALLOW_COPYING(Tokenizer);

public:
    Tokenizer(const FTSLanguage* language, StringData str);

    bool more() const;
    Token next();

private:
    Token::Type _type(char c) const;
    bool _skipWhitespace();

    unsigned _pos;
    const StringData _raw;
    bool _english;
};
}
}
